@@ -165,19 +165,20 @@ class Config(object):
     def commandline(cls, args):
         """Configure remote system"""
 
-        # FIXME: Refactor relict - remove later
-        log = logging.getLogger("cdist")
+        if (args.parallel and args.parallel != 1) or args.jobs:
+            if args.timestamp:
+                cdist.log.setupTimestampingParallelLogging()
+            else:
+                cdist.log.setupParallelLogging()
+        elif args.timestamp:
+            cdist.log.setupTimestampingLogging()
+        log = logging.getLogger("config")
 
         # No new child process if only one host at a time.
         if args.parallel == 1:
             log.debug("Only 1 parallel process, doing it sequentially")
             args.parallel = 0
 
-        if args.parallel or args.jobs:
-            # If parallel execution then also log process id
-            cdist.log.setupParallelLogging()
-            log = logging.getLogger("cdist")
-
         if args.parallel:
             import signal
 
@@ -555,19 +556,19 @@ class Config(object):
             self.log.trace("Multiprocessing cargo_types: %s", cargo_types)
             nt = len(cargo_types)
             if nt == 1:
-                self.log.debug(("Only one type, transfering explorers "
+                self.log.debug(("Only one type, transferring explorers "
                                 "sequentially"))
                 self.explorer.transfer_type_explorers(cargo_types.pop())
             else:
                 self.log.trace(("Starting multiprocessing Pool for {} "
-                                "parallel transfering types' explorers".format(
+                                "parallel types explorers transferring".format(
                                     nt)))
                 args = [
                     (ct, ) for ct in cargo_types
                 ]
                 mp_pool_run(self.explorer.transfer_type_explorers, args,
                             jobs=self.jobs)
-                self.log.trace(("Multiprocessing for parallel transfering "
+                self.log.trace(("Multiprocessing for parallel transferring "
                                 "types' explorers finished"))
 
             self.log.trace(("Starting multiprocessing Pool for {} parallel "
