@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# 2011 Steven Armstrong (steven-cdist at armstrong.cc)
+# 2011-2013 Steven Armstrong (steven-cdist at armstrong.cc)
 # 2011-2013 Nico Schottelius (nico-cdist at schottelius.org)
 #
 # This file is part of cdist.
@@ -24,6 +24,7 @@ import logging
 import os
 
 import cdist
+from . import util
 
 '''
 common:
@@ -42,6 +43,7 @@ common:
                                 types are defined for use in type emulator
             == local.type_path
         __files: full qualified path to the files dir
+        __target_host_tags: comma spearated list of host tags
 
 initial manifest is:
     script: full qualified path to the initial manifest
@@ -98,7 +100,7 @@ class Manifest(object):
         self.target_host = target_host
         self.local = local
 
-        self.log = logging.getLogger(self.target_host[0])
+        self._open_logger()
 
         self.env = {
             'PATH': "%s:%s" % (self.local.bin_path, os.environ['PATH']),
@@ -109,10 +111,26 @@ class Manifest(object):
             '__target_hostname': self.target_host[1],
             '__target_fqdn': self.target_host[2],
             '__files': self.local.files_path,
+            '__target_host_tags': self.local.target_host_tags,
+            '__cdist_log_level': util.log_level_env_var_val(self.log),
+            '__cdist_log_level_name': util.log_level_name_env_var_val(
+                self.log),
         }
 
-        if self.log.getEffectiveLevel() == logging.DEBUG:
-            self.env.update({'__cdist_debug': "yes"})
+    def _open_logger(self):
+        self.log = logging.getLogger(self.target_host[0])
+
+    # logger is not pickable, so remove it when we pickle
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        if 'log' in state:
+            del state['log']
+        return state
+
+    # recreate logger when we unpickle
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        self._open_logger()
 
     def env_initial_manifest(self, initial_manifest):
         env = os.environ.copy()
@@ -130,15 +148,27 @@ class Manifest(object):
         else:
             user_supplied = True
 
-        self.log.info("Running initial manifest " + initial_manifest)
-
         if not os.path.isfile(initial_manifest):
             raise NoInitialManifestError(initial_manifest, user_supplied)
 
         message_prefix = "initialmanifest"
-        self.local.run_script(initial_manifest,
-                              env=self.env_initial_manifest(initial_manifest),
-                              message_prefix=message_prefix)
+        self.log.verbose("Running initial manifest " + initial_manifest)
+        which = "init"
+        if self.local.save_output_streams:
+            stderr_path = os.path.join(self.local.stderr_base_path, which)
+            stdout_path = os.path.join(self.local.stdout_base_path, which)
+            with open(stderr_path, 'ba+') as stderr, \
+                    open(stdout_path, 'ba+') as stdout:
+                self.local.run_script(
+                    initial_manifest,
+                    env=self.env_initial_manifest(initial_manifest),
+                    message_prefix=message_prefix,
+                    stdout=stdout, stderr=stderr)
+        else:
+            self.local.run_script(
+                initial_manifest,
+                env=self.env_initial_manifest(initial_manifest),
+                message_prefix=message_prefix)
 
     def env_type_manifest(self, cdist_object):
         type_manifest = os.path.join(self.local.type_path,
@@ -160,7 +190,22 @@ class Manifest(object):
         type_manifest = os.path.join(self.local.type_path,
                                      cdist_object.cdist_type.manifest_path)
         message_prefix = cdist_object.name
+        which = 'manifest'
         if os.path.isfile(type_manifest):
-            self.local.run_script(type_manifest,
-                                  env=self.env_type_manifest(cdist_object),
-                                  message_prefix=message_prefix)
+            self.log.verbose("Running type manifest %s for object %s",
+                             type_manifest, cdist_object.name)
+            if self.local.save_output_streams:
+                stderr_path = os.path.join(cdist_object.stderr_path, which)
+                stdout_path = os.path.join(cdist_object.stdout_path, which)
+                with open(stderr_path, 'ba+') as stderr, \
+                        open(stdout_path, 'ba+') as stdout:
+                    self.local.run_script(
+                        type_manifest,
+                        env=self.env_type_manifest(cdist_object),
+                        message_prefix=message_prefix,
+                        stdout=stdout, stderr=stderr)
+            else:
+                self.local.run_script(
+                    type_manifest,
+                    env=self.env_type_manifest(cdist_object),
+                    message_prefix=message_prefix)
