@@ -63,6 +63,10 @@ cdist/conf/
     The distribution configuration directory.
     This contains types and explorers to be used.
 
+cdist/inventory/
+    The distribution inventory directory.
+    This path is relative to cdist installation directory.
+
 confdir
     Cdist will use all available configuration directories and create
     a temporary confdir containing links to the real configuration directories.
@@ -194,6 +198,29 @@ Environment variables (for reading)
 -----------------------------------
 The following environment variables are exported by cdist:
 
+__cdist_log_level, __cdist_log_level_name
+    cdist log level value and cdist log level name. One of:
+
+    +----------------+-----------------+
+    | Log level name | Log level value |
+    +================+=================+
+    | OFF            | 60              |
+    +----------------+-----------------+
+    | ERROR          | 40              |
+    +----------------+-----------------+
+    | WARNING        | 30              |
+    +----------------+-----------------+
+    | INFO           | 20              |
+    +----------------+-----------------+
+    | VERBOSE        | 15              |
+    +----------------+-----------------+
+    | DEBUG          | 10              |
+    +----------------+-----------------+
+    | TRACE          | 5               |
+    +----------------+-----------------+
+
+    Available for: initial manifest, explorer, type manifest, type explorer,
+    type gencode.
 __explorer
     Directory that contains all global explorers.
     Available for: initial manifest, explorer, type explorer, shell.
@@ -239,6 +266,9 @@ __target_fqdn
     This variable is derived from **__target_host**
     (using **socket.getfqdn()**).
     Available for: explorer, initial manifest, type explorer, type manifest, type gencode, shell.
+__target_host_tags
+    Comma separated list of target host tags.
+    Available for: explorer, initial manifest, type explorer, type manifest, type gencode, shell.
 __type
     Path to the current type.
     Available for: type manifest, type gencode.
@@ -253,6 +283,32 @@ The following environment variables influence the behaviour of cdist:
 require
     Setup dependencies between objects (see \`cdist manifest <cdist-manifest.html>\`_).
 
+__cdist_log_level
+    cdist log level value. One of:
+
+    +----------------+-----------------+
+    | Log level      | Log level value |
+    +================+=================+
+    | OFF            | 60              |
+    +----------------+-----------------+
+    | ERROR          | 40              |
+    +----------------+-----------------+
+    | WARNING        | 30              |
+    +----------------+-----------------+
+    | INFO           | 20              |
+    +----------------+-----------------+
+    | VERBOSE        | 15              |
+    +----------------+-----------------+
+    | DEBUG          | 10              |
+    +----------------+-----------------+
+    | TRACE          | 5               |
+    +----------------+-----------------+
+
+    If set cdist will set this log level in
+    accordance with configuration rules. If cdist invokation is used
+    in types then nested cdist will honor this specified log level if
+    not specified otherwise while invoking it.
+
 CDIST_PATH
     Colon delimited list of config directories.
 
@@ -274,6 +330,12 @@ CDIST_REMOTE_EXEC
 CDIST_REMOTE_COPY
     Use this command for remote copy (should behave like scp).
 
+CDIST_INVENTORY_DIR
+    Use this directory as inventory directory.
+
 CDIST_BETA
     Enable beta functionalities.
+
+CDIST_CACHE_PATH_PATTERN
+    Custom cache path pattern.
 eof
